@@ -452,6 +452,14 @@ class ClearingHouse:
     async def cancel_orders(
         self,
         user_id: int = 0
+    ): 
+        return await self.send_ixs(
+            await self.get_cancel_orders_ix(user_id)
+        )
+    
+    async def get_cancel_orders_ix(
+        self,
+        user_id: int = 0
     ): 
         remaining_accounts = await self.get_remaining_accounts(user_id=user_id)
 
@@ -505,12 +513,19 @@ class ClearingHouse:
         direction: PositionDirection,
         amount: int,
         market_index: int,
+        user_id: int = 0,
         limit_price: int = 0,
         ioc: bool = False,
-        user_id: int = 0,
     ):
         return await self.send_ixs(
-            await self.get_open_position_ix(direction, amount, market_index, limit_price, ioc, user_id=user_id),
+            await self.get_open_position_ix(
+                direction,
+                amount,
+                market_index, 
+                user_id,
+                limit_price,
+                ioc,
+            ),
         )
 
     async def get_open_position_ix(
@@ -713,7 +728,7 @@ class ClearingHouse:
     ):
         return await self.send_ixs(
             await self.get_close_position_ix(
-                market_index, limit_price, subaccount_id
+                market_index, limit_price, subaccount_id=subaccount_id
             )
         )
 
@@ -737,7 +752,7 @@ class ClearingHouse:
         order.limit_price = limit_price
         order.reduce_only = True
 
-        ix = await self.get_place_and_take_ix(order)
+        ix = await self.get_place_and_take_ix(order, subaccount_id=subaccount_id)
         return ix
 
     def default_order_params(
